summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2001-06-21 00:23:28 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2001-06-21 00:23:28 +0000
commitb19c56004f13f1576e0524bd078aebc85fd737f3 (patch)
tree0462f2903a4d6aa2f1c5c9114bd075bc66d208ce
parent888e562e72651351ffabd7e84f64370363af235a (diff)
downloadATCD-b19c56004f13f1576e0524bd078aebc85fd737f3.tar.gz
ChangeLogTag: Wed Jun 20 19:20:15 2001 Irfan Pyarali <irfan@cs.wustl.edu>
-rw-r--r--TAO/ChangeLogs/ChangeLog-02a19
-rw-r--r--TAO/tests/RTCORBA/Banded_Connections/bands.unix2
-rwxr-xr-xTAO/tests/RTCORBA/Banded_Connections/run_test.pl12
3 files changed, 26 insertions, 7 deletions
diff --git a/TAO/ChangeLogs/ChangeLog-02a b/TAO/ChangeLogs/ChangeLog-02a
index e9b89ecd92d..0e617ce0e77 100644
--- a/TAO/ChangeLogs/ChangeLog-02a
+++ b/TAO/ChangeLogs/ChangeLog-02a
@@ -1,3 +1,17 @@
+Wed Jun 20 19:20:15 2001 Irfan Pyarali <irfan@cs.wustl.edu>
+
+ * tests/RTCORBA/Banded_Connections/run_test.pl:
+ * tests/RTCORBA/Banded_Connections/bands.unix:
+
+ There was a change in priority ranges between Solaris 5.7 and
+ 5.8. For the SCHED_OTHER policy, the ranges are:
+
+ Sun 5.8 Minimum = 0 Maximum = 59
+ Sun 5.7 Minimum = -60 Maximum = 60
+
+ Therefore, the above scripts were updated to reflect the new
+ range. Similar changes may be needed for the other RT tests.
+
Wed Jun 20 18:45:40 2001 Angelo Corsaro <corsaro@cs.wustl.edu>
* performance-tests/RTCorba/Multiple_Endpoints/Common/Makefile:
@@ -1485,6 +1499,11 @@ Mon Jun 11 16:56:06 2001 Balachandran <bala@cs.wustl.edu>
* TAO version 1.1.17 released.
+Mon Jun 11 11:51:06 2001 Irfan Pyarali <irfan@cs.wustl.edu>
+
+ * tests/RTCORBA/Banded_Connections/run_test.pl: Fixed the scripts
+ for execution on NT.
+
Mon Jun 11 11:26:38 2001 Priyanka Gontla <pgontla@ece.uci.edu>
* orbsvcs/tests/Security/Secure_Invocation/client_cert.pem:
diff --git a/TAO/tests/RTCORBA/Banded_Connections/bands.unix b/TAO/tests/RTCORBA/Banded_Connections/bands.unix
index 079ae9bf99f..14398bf3c1f 100644
--- a/TAO/tests/RTCORBA/Banded_Connections/bands.unix
+++ b/TAO/tests/RTCORBA/Banded_Connections/bands.unix
@@ -1 +1 @@
-65 69 70 76 77 80
+35 39 40 46 47 50
diff --git a/TAO/tests/RTCORBA/Banded_Connections/run_test.pl b/TAO/tests/RTCORBA/Banded_Connections/run_test.pl
index a6b0037536b..87ab1a0e7a6 100755
--- a/TAO/tests/RTCORBA/Banded_Connections/run_test.pl
+++ b/TAO/tests/RTCORBA/Banded_Connections/run_test.pl
@@ -20,21 +20,21 @@ unlink $iorfile2;
print STDERR "\n********** RTCORBA Priority Banded Connections Unit Test\n";
# CORBA priorities 66, 75 and 80, etc. are for the SCHED_OTHER class on
# Solaris. May need to use different values for other platforms
# depending on their native priorities scheme, i.e., based on the
# available range.
$server_args =
"-n $iorfile1 -o $iorfile2 -b bands.unix -ORBSvcConf $server_conf "
- ."-p 67 -w 81 "
- ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=69 "
- ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=76 "
- ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=80 ";
+ ."-p 37 -w 51 "
+ ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=39 "
+ ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=46 "
+ ."-ORBendpoint iiop://$TARGETHOSTNAME:0/priority=50 ";
$client_args =
"-n file://$iorfile1 -o file://$iorfile2 "
- ."-a 67 -b 75 -c 90";
+ ."-a 37 -b 45 -c 56";
if ($^O eq "MSWin32") {
$server_args =
@@ -20,21 +20,21 @@ unlink $iorfile2;
print STDERR "\n********** RTCORBA Priority Banded Connections Unit Test\n";
-# CORBA priorities 66, 75 and 80, etc. are for the SCHED_OTHER class on
+# CORBA priorities 37, 45 and 50, etc. are for the SCHED_OTHER class on
# Solaris. May need to use different values for other platforms
# depending on their native priorities scheme, i.e., based on the